This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/nuttx.git


The following commit(s) were added to refs/heads/master by this push:
     new 8ac09bcf3d arch/arm/rp23xx: Fix IRQ prioritize
8ac09bcf3d is described below

commit 8ac09bcf3da207c26ebb21beb0c999244e0d8e14
Author: Serg Podtynnyi <s...@podtynnyi.com>
AuthorDate: Tue Apr 15 17:11:51 2025 +0700

    arch/arm/rp23xx: Fix IRQ prioritize
    
    Fixes the reg addresses that were copied from armv6 rp2040 to the actual
    armv8 spec
    
    Signed-off-by: Serg Podtynnyi <s...@podtynnyi.com>
---
 arch/arm/src/rp23xx/rp23xx_irq.c | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/arch/arm/src/rp23xx/rp23xx_irq.c b/arch/arm/src/rp23xx/rp23xx_irq.c
index 2bf5e4975e..b2ce035221 100644
--- a/arch/arm/src/rp23xx/rp23xx_irq.c
+++ b/arch/arm/src/rp23xx/rp23xx_irq.c
@@ -466,11 +466,11 @@ int up_prioritize_irq(int irq, int priority)
 
   if (irq >= RP23XX_IRQ_EXTINT && irq < RP23XX_IRQ_EXTINT + 32)
     {
       /* ARMV6M_NVIC_IPR() maps register IPR0-IPR7 with four settings per
        * register.
        */
 
-      regaddr = ARMV6M_NVIC_IPR(irq >> 2);
+      regaddr = NVIC_IRQ_PRIORITY(irq);
       shift   = (irq & 3) << 3;
     }
 
@@ -481,13 +481,13 @@ int up_prioritize_irq(int irq, int priority)
 
   else if (irq == RP23XX_IRQ_PENDSV)
     {
-      regaddr = ARMV6M_SYSCON_SHPR2;
-      shift   = SYSCON_SHPR3_PRI_14_SHIFT;
+      regaddr = NVIC_SYSH12_15_PRIORITY;
+      shift   = NVIC_SYSH_PRIORITY_PR14_SHIFT;
     }
   else if (irq == RP23XX_IRQ_SYSTICK)
     {
-      regaddr = ARMV6M_SYSCON_SHPR2;
-      shift   = SYSCON_SHPR3_PRI_15_SHIFT;
+      regaddr = NVIC_SYSH12_15_PRIORITY;
+      shift   = NVIC_SYSH_PRIORITY_PR15_SHIFT;
     }
   else
     {
@@ -466,11 +466,11 @@ int up_prioritize_irq(int irq, int priority)
   if (irq >= RP23XX_IRQ_EXTINT && irq < RP23XX_IRQ_EXTINT + 32)
     {
-      /* ARMV6M_NVIC_IPR() maps register IPR0-IPR7 with four settings per
+      /* NVIC_IRQ_PRIORITY maps register IPR0-IPR7 with four settings per
        * register.
        */

Reply via email to